@@ -30,13 +30,6 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------
 
-#import os
-#import sys
-
-import utils
-from mreorg.utils import ensure_directory_exists
-from mreorg.utils import get_file_sha1hash
-
 from mreorg.scriptplots import PlotManager, PM
 from mreorg.scriptplots import FigFormat
 from mreorg.scriptflags import ScriptFlags
@@ -46,7 +39,6 @@ from mreorg.config import MReOrgConfig
 from mreorg.layouts import FigureLayouts
 from mreorg.layouts import FigureOptions
 
-
 # OK< now lets do some monkey-patching
 import mreorg.requiredpreimport
 
@@ -56,8 +48,6 @@ __all__ = [
     'PlotManager',
     'PM',
     'FigFormat',
-    'ensure_directory_exists',
-    'get_file_sha1hash',
     'FigureLayouts',
     'FigureOptions',
     ]
