@@ -44,7 +44,6 @@ if not ScriptFlags.MREORG_DONTIMPORTMATPLOTLIB:
     import matplotlib
     is_running_headless = not os.environ.get('DISPLAY', None)
 
-
     # Preconfiguration, before we import pylab:
     if ScriptFlags.MREORG_MPLCONFIG_FILE:
         print 'Custom MPLConfig', ScriptFlags.MREORG_MPLCONFIG_FILE
@@ -69,7 +68,9 @@ if not ScriptFlags.MREORG_DONTIMPORTMATPLOTLIB:
         mpl_rcparams = config.get('matplotlib', {})
 
         # Downscale values set in mreorg, if needs be. (This is to work around a bug(?) in matplotlib SVG backend):
-        downscale_options = ['font.size','axes.labelsize','legend.fontsize','xtick.labelsize','ytick.labelsize']
+        downscale_options = ['font.size', 'axes.labelsize',
+                             'legend.fontsize', 'xtick.labelsize',
+                             'ytick.labelsize']
         if FigureOptions.downscale_fontsize:
             for k in downscale_options:
                 if k in mpl_rcparams.keys():
@@ -101,10 +102,10 @@ if not ScriptFlags.MREORG_DONTIMPORTMATPLOTLIB:
     matplotlib.pylab.show = show
     pylab.show = show
 
-
     # Monkey-Patch 'matplotlib.savefig()' and 'pylab.savefig()', allowing us
     # to save to directories that don't exist by automatically creating them:
     orig_mplsavefig = matplotlib.pylab.savefig
+
     def savefig(filename, *args, **kwargs):
         from mreorg.layouts import FigureOptions
         from mreorg.utils import ScriptUtils
@@ -127,28 +128,6 @@ if not ScriptFlags.MREORG_DONTIMPORTMATPLOTLIB:
 
 
 
-
-
-    ## Trigger saving all images at the end of the program run:
-    #if ScriptFlags.MREORG_SAVEALL:
-    #    
-    #    from mreorg.atexithandlers import AtExitHandler
-    #    def _save_all_at_exit(*args,**kwargs):
-    #        print 'Saving atexit:'
-    #        from mreorg.scriptplots import PlotManager
-    #        PlotManager.save_active_figures()
-
-
-    #    AtExitHandler.add_handler(_save_all_at_exit)
-
-
-
-
-
-
-
-
-
     # Monkey patch xlabel, ylabel, so the default is
     # multialignment='center'
     from matplotlib import axes
@@ -200,10 +179,8 @@ if ScriptFlags.MREORG_ENABLECOVERAGE:
     import coverage
     coverage.process_startup()
 
-
-
 if ScriptFlags.MREORG_CURATIONRUN:
     #assert False
-    from mreorg.curator.backend_sim.db_writer_hooks import CurationSimDecorator
+    from mreorg.curator.backend.db_writer_hooks import CurationSimDecorator
     CurationSimDecorator.activate()
 
