@@ -33,10 +33,11 @@
 import os
 
 import mreorg
-from mreorg.utils import ScriptUtils
 from mreorg.layouts import FigureOptions
 from mreorg.config import MReOrgConfig
 
+import mhutils
+
 
 class FigFormat:
 
@@ -105,7 +106,7 @@ class PlotManager:
 
         # Find the module this function was called from:
 
-        modname = ScriptUtils.get_calling_script_file(include_ext=False)
+        modname = mhutils.fs.scripts.ScriptUtils.get_calling_script_file(include_ext=False)
 
         # Print what we are saving:
         subst_dict = {
@@ -165,5 +166,3 @@ class PlotManager:
                                     % fig.number, figure=fig)
 
 
-
-
